Documentation
¶
Index ¶
- Variables
- func AnalyticsBetweenDates(c *gin.Context)
- func CORSMiddleware() gin.HandlerFunc
- func CurrentSessions(c *gin.Context)
- func DBConnection()
- func GoDotEnvVariable(key string) string
- func HeartBeats(c *gin.Context)
- func RegisterApikey(c *gin.Context)
- func TemplateParser(template_name string, context map[string]string) string
- func Update_asked_location_websites(c *gin.Context)
- func VisitorResults(c *gin.Context)
- func VisitorScript(c *gin.Context)
- type AnalyticResult
- type ApiKey
Constants ¶
This section is empty.
Variables ¶
var SECRET_KEY string = GoDotEnvVariable("SECRET_KEY")
Functions ¶
func CurrentSessions ¶
CurrentSessions: Description: Return a list of the live sessions of a website Endpoint: /DJANGO/get_sessions/ Input:
host= website host apikey= owner apikey seconds= seconds behind to consider a visitor as a live session
Output:
results= Sessions filtered
func DBConnection ¶
func DBConnection()
func GoDotEnvVariable ¶
use godot package to load/read the .env file and return the value of the key
func HeartBeats ¶
func RegisterApikey ¶
NewApiKey
Description: Generate a new and unique apikey in database Endpoint: Input: secret_key: Authentication secret key end_date: End date of website track style "YYYY-mm-dd" Output: JSON with results
func TemplateParser ¶
CLIENT BROWSER ENDPOINTS
func Update_asked_location_websites ¶
Deprecated
func VisitorResults ¶
func VisitorScript ¶
Types ¶
type AnalyticResult ¶
type AnalyticResult struct {
//Server stats
Key string
Session_id string
Session_start string
Session_end string
// Client stats
Host string
Path string
Date string
Referrer string
ReferrerPath string
Time string
Performance float64
Latitude float64
Longitude float64
IsPhone bool
Country string
City string
Region string
CountryCode string
Ip string
Browser string
OS string
}
Click to show internal directories.
Click to hide internal directories.